.. _notebooks:

Notebooks
=========

IB-insync can be used in a fully interactive, exploratory way with live data from
within a `Jupyter <http://jupyter.org>`_ notebook.
Here are some recipe notebooks:

.. toctree::
   :maxdepth: 2

   Basics <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/basics.ipynb>
   Contract details <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/contract_details.ipynb>
   Option chain <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/option_chain.ipynb>
   Bar data <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/bar_data.ipynb>
   Tick data <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/tick_data.ipynb>
   Market depth <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/market_depth.ipynb>
   Ordering <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/ordering.ipynb>
   Scanners <https://nbviewer.jupyter.org/github/erdewit/ib_insync/tree/master/notebooks/scanners.ipynb>


